# The FlexMeasures Platform

![lint-and-test](https://github.com/SeitaBV/flexmeasures/workflows/lint-and-test/badge.svg)
[![](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/downloads/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/flexmeasures/badge/?version=latest)](https://flexmeasures.readthedocs.io/en/latest/?badge=latest)

The *FlexMeasures Platform* is a tool for scheduling flexible actions for energy assets.
For this purpose, it performs monitoring, forecasting and scheduling services.

![Separation of concerns ― FlexMeasures enhancing Energy Service Company services](https://seita.nl/wp-content/uploads/2021/02/SeparationOfConcerns.png)


Its role is to enhance energy services. Forecasts and schedules are made available via API (designed with [the USEF framework](https://usef.energy) in mind).

![Integration view of the FlexMeasures platform architecture](https://seita.nl/wp-content/uploads/2021/02/FlexMeasures-HighLevel.png)

FlexMeasures is developed by [Seita BV](https://www.seita.nl) in The Netherlands, in cooperation with [A1 Engineering](http://aoneeng.com), Korea.

We made FlexMeasures freely available under the Apache2.0 licence. Please get in contact if you use FlexMeasures or are considering it. More information on [FlexMeasures.io](https://flexmeasures.io).


Head over to our documentation on [getting started](https://flexmeasures.readthedocs.io/en/latest/getting-started.html)!

